MemoryAllocation

Struct MemoryAllocation 

pub struct MemoryAllocation { /* private fields */ }
Memory allocation handle

The allocation handle tracks its current position in the pool. During defragmentation, the offset may change, but this is handled transparently through the pool’s relocation table.

Implementations

Source

impl MemoryAllocation

pub fn offset(&self) -> u64

Get allocation offset

This looks up the current offset from the pool’s relocation table, which handles offset changes due to defragmentation.

pub fn size(&self) -> u64

Get allocation size

pub fn range(&self) -> Range<u64>

Get allocation range

pub fn id(&self) -> u64

Get allocation ID